==> openjdk-18_18~36ea.orig.tar.xz: openjdk-18-18~36ea/src/hotspot/share/runtime/safepointVerifiers.cpp <==
/*
 * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#include "precompiled.hpp"
#include "gc/shared/collectedHeap.hpp"
#include "memory/universe.hpp"
#include "runtime/safepoint.hpp"
#include "runtime/safepointVerifiers.hpp"
#include "utilities/debug.hpp"

#ifdef ASSERT

NoSafepointVerifier::NoSafepointVerifier() : _thread(Thread::current()) {
  if (_thread->is_Java_thread()) {
    JavaThread::cast(_thread)->inc_no_safepoint_count();
  }
}

NoSafepointVerifier::~NoSafepointVerifier() {
  if (_thread->is_Java_thread()) {
    JavaThread::cast(_thread)->dec_no_safepoint_count();
  }
}

PauseNoSafepointVerifier::PauseNoSafepointVerifier(NoSafepointVerifier* nsv)
    : _nsv(nsv) {
  assert(_nsv->_thread == Thread::current(), "must be");
  if (_nsv->_thread->is_Java_thread()) {
    JavaThread::cast(_nsv->_thread)->dec_no_safepoint_count();
  }
}

PauseNoSafepointVerifier::~PauseNoSafepointVerifier() {
  if (_nsv->_thread->is_Java_thread()) {
    JavaThread::cast(_nsv->_thread)->inc_no_safepoint_count();
  }
}
#endif // ASSERT

==> openjdk-26_26~34ea.orig.tar.xz: openjdk-26-26~34ea/src/hotspot/share/runtime/safepointVerifiers.cpp <==
/*
 * Copyright (c) 1997, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#include "gc/shared/collectedHeap.hpp"
#include "memory/universe.hpp"
#include "runtime/safepoint.hpp"
#include "runtime/safepointVerifiers.hpp"
#include "utilities/debug.hpp"

#ifdef ASSERT

NoSafepointVerifier::NoSafepointVerifier(bool active) : _thread(Thread::current()), _active(active) {
  if (!_active) {
    return;
  }
  if (_thread->is_Java_thread()) {
    JavaThread::cast(_thread)->inc_no_safepoint_count();
  }
}

NoSafepointVerifier::~NoSafepointVerifier() {
  if (!_active) {
    return;
  }
  if (_thread->is_Java_thread()) {
    JavaThread::cast(_thread)->dec_no_safepoint_count();
  }
}

PauseNoSafepointVerifier::PauseNoSafepointVerifier(NoSafepointVerifier* nsv)
    : _nsv(nsv) {
  assert(_nsv->_thread == Thread::current(), "must be");
  if (_nsv->_thread->is_Java_thread()) {
    JavaThread::cast(_nsv->_thread)->dec_no_safepoint_count();
  }
}

PauseNoSafepointVerifier::~PauseNoSafepointVerifier() {
  if (_nsv->_thread->is_Java_thread()) {
    JavaThread::cast(_nsv->_thread)->inc_no_safepoint_count();
  }
}
#endif // ASSERT
